@@ -1,13 +1,15 @@
 from __future__ import annotations
+from types import NoneType
 from typing import Callable, ClassVar, Optional, TYPE_CHECKING, TypeVar
 from os import getcwd, path
 from inflection import parameterize, camelize
+from jsonclasses.uconf import uconf
 from pymongo.mongo_client import MongoClient
 from pymongo.database import Database
 from pymongo.collection import Collection
 if TYPE_CHECKING:
-    from .pymongo_object import PymongoObject
-    T = TypeVar('T', bound=PymongoObject, covariant=True)
+    from .pobject import PObject
+    T = TypeVar('T', bound=PObject, covariant=True)
 
 
 ConnectedCallback = Callable[[Collection], None]
@@ -49,9 +51,15 @@ class Connection:
         self._url = url
 
     def _generate_default_url(self: Connection) -> str:
+        if self.graph_name == 'default':
+            user_url = uconf()['pymongo.url'] or uconf()['pymongo.default.url']
+        else:
+            user_url = uconf()[f'pymongo.{self.graph_name}.url']
+        if user_url is not None:
+            self._url = user_url
+            return user_url
         base = 'mongodb://localhost:27017/'
-        cwd = getcwd()
-        proj = camelize(parameterize(path.basename(cwd))).lower()
+        proj = camelize(parameterize(path.basename(getcwd()))).lower()
         self._url = base + proj
         return self._url
 
@@ -89,7 +97,7 @@ class Connection:
         return self._connected
 
     def collection(self: Connection, name: str, index_keys: list[str] | None = None) -> Collection:
-        if self._collections.get(name):
+        if self._collections.get(name) is not None:
             return self._collections[name]
         coll = self.database.get_collection(name)
         if index_keys is not None:
