@@ -1,22 +1,17 @@
 from __future__ import annotations
 from typing import Any, Optional, TypeVar, cast, TYPE_CHECKING
-from datetime import date
+from datetime import date, timezone
 from jsonclasses.types import Types
 from jsonclasses.fdef import FStore, FType
 from jsonclasses.mgraph import MGraph
-from inflection import camelize
-from .utils import (
-    ref_field_key, ref_field_keys, ref_db_field_key, ref_db_field_keys
-)
-from .coder import Coder
-from .pconf import PConf
+from .utils import (ref_db_field_key, ref_db_field_keys)
 if TYPE_CHECKING:
     from .query import BaseQuery
-    from .pymongo_object import PymongoObject
-    T = TypeVar('T', bound=PymongoObject)
+    from .pobject import PObject
+    T = TypeVar('T', bound=PObject)
 
 
-class Decoder(Coder):
+class Decoder:
 
     def decode_list(self,
                     value: list[Any],
@@ -54,6 +49,8 @@ class Decoder(Coder):
             return value
         if types.fdef.ftype == FType.DATE:
             return date.fromisoformat(value.isoformat()[:10])
+        elif types.fdef.ftype == FType.DATETIME:
+            return value.replace(tzinfo=timezone.utc)
         elif types.fdef.ftype == FType.ENUM:
             if isinstance(types.fdef.enum_class, str):
                 enum_cls = cast(type, types.fdef.enum_class)
@@ -86,15 +83,12 @@ class Decoder(Coder):
             dest = cls()
             exist = False
         for field in cls.cdef.fields:
-            if cls.pconf.camelize_db_keys:
-                key = camelize(field.name, False)
-            else:
-                key = field.name
-            if self.is_id_field(field):
+            key = cls.pconf.to_db_key(field.name)
+            if field.is_primary:
                 if not exist:
                     setattr(dest, field.name, inst_id)
                     graph.put(dest)
-            elif self.is_foreign_key_storage(field):
+            elif field.is_foreign_key_store:
                 if value.get(key) is not None:
                     subquery = None
                     if query:
@@ -111,7 +105,7 @@ class Decoder(Coder):
                                 self.decode_instance(
                                     cast(dict[str, Any], value.get(key)),
                                     new_cls, field.types, graph, subquery))
-            elif self.is_local_key_reference_field(field):
+            elif field.is_local_one_ref:
                 if value.get(key) is not None:
                     subquery = None
                     if query:
@@ -122,12 +116,12 @@ class Decoder(Coder):
                         graph=graph, query=subquery)
                     setattr(dest, field.name, inst)
                 ref_id = value.get(ref_db_field_key(field.name, cls=cls))
-                rfk = ref_field_key(field.name)
+                rfk = field.ref_name
                 setattr(dest, rfk, str(ref_id))
                 if query and hasattr(query, '_final_pick'):
                     if rfk not in query._final_pick:
                         setattr(dest, rfk, None)
-            elif self.is_local_keys_reference_field(field):
+            elif field.is_local_many_ref:
                 if value.get(key) is not None:
                     subquery = None
                     if query:
@@ -138,9 +132,8 @@ class Decoder(Coder):
                                 value[key], new_cls, field.types, graph, subquery))
                 saved_keys = value.get(ref_db_field_keys(field.name, cls))
                 if saved_keys:
-                    setattr(dest, ref_field_keys(field.name),
-                            [str(k) for k in saved_keys])
-            elif self.is_instance_field(field):
+                    setattr(dest, field.ref_name, [str(k) for k in saved_keys])
+            elif field.is_inst_field:
                 new_cls = field.fdef.inst_cls
                 setattr(dest, field.name, self.decode_item(
                     value=value.get(key), types=field.types, cls=new_cls,
@@ -167,10 +160,10 @@ class Decoder(Coder):
             return
         graph.put(root)
         for field in root.__class__.cdef.fields:
-            if self.is_instance_field(field):
+            if field.is_inst_field:
                 if getattr(root, field.name) is not None:
                     self.apply_unmodified_status(getattr(root, field.name), graph)
-            elif self.is_list_instance_field(field, root.__class__):
+            elif field.is_list_inst_field:
                 if getattr(root, field.name) is not None:
                     for item in getattr(root, field.name):
                         self.apply_unmodified_status(item, graph)
