@@ -1,24 +1,22 @@
 from __future__ import annotations
-from typing import TypeVar, Any, Union, cast
+from typing import TypeVar, Any, cast
 from re import search
 from bson.objectid import ObjectId
 from jsonclasses.jfield import JField
 from pymongo.errors import DuplicateKeyError
 from pymongo.collection import Collection
 from pymongo import ASCENDING
-from jsonclasses.fdef import FStore, FType
+from jsonclasses.fdef import FStore, FType, FSubtype
 from jsonclasses.excs import UniqueConstraintException
 from jsonclasses.excs import DeletionDeniedException
-from inflection import underscore, camelize
-from .pymongo_object import PymongoObject
+from .pobject import PObject
 from .query import BaseQuery, ExistQuery, IDSQuery, IterateQuery, ListQuery, SingleQuery, IDQuery
 from .encoder import Encoder
 from .connection import Connection
-from .utils import ref_db_field_key
-from .coder import Coder
+from .utils import ref_db_field_key, join_table_name
 
 
-T = TypeVar('T', bound=PymongoObject)
+T = TypeVar('T', bound=PObject)
 
 
 def find(cls: type[T], *args, **kwargs: Any) -> ListQuery[T]:
@@ -79,23 +77,24 @@ def _database_write(self: T) -> None:
             db_key = index_key
             single_key = False
         if single_key:
-            pt_key = db_key
-            if self.__class__.pconf.camelize_db_keys:
-                pt_key = underscore(db_key)
+            pt_key = self.__class__.pconf.to_py_key(db_key)
             raise UniqueConstraintException(pt_key) from None
         else:
             results = []
             for field in self.__class__.cdef.fields:
                 if field.fdef.cindex and db_key in field.fdef.cindex_names:
                     results.append(field.name)
-            ek = self.__class__.cdef.jconf.key_encoding_strategy
+            ek = self.__class__.cdef.jconf.output_key_strategy
             raise UniqueConstraintException([ek(r) for r in results], f'voilated unique compound index \'{index_key}\'')
 
 def _orm_delete(self: T, no_raise: bool = False) -> None:
+    self_id = self._id
+    if self.__class__.cdef.primary_field.fdef.fsubtype == FSubtype.MONGOID:
+        self_id = ObjectId(self_id)
     # deny test
     for field in self.__class__.cdef.deny_fields:
         if field.fdef.fstore == FStore.LOCAL_KEY:
-            key = self.__class__.cdef.jconf.ref_key_encoding_strategy(field)
+            key = self.__class__.cdef.jconf.ref_name_strategy(field)
             if hasattr(self, key) and getattr(self, key) is not None:
                 if no_raise:
                     return
@@ -108,14 +107,10 @@ def _orm_delete(self: T, no_raise: bool = False) -> None:
                 oc = field.fdef.inst_cls
             f = cast(JField, field.foreign_field)
             if field.fdef.use_join_table:
-                jtname = Coder().join_table_name(
-                    self.__class__,
-                    field.name,
-                    oc,
-                    f.name)
+                jtname = join_table_name(field)
                 coll = Connection.from_class(self.__class__).collection(jtname)
                 key = ref_db_field_key(self.__class__.__name__, self.__class__)
-                e = coll.count_documents({key: ObjectId(self._id)}, limit=1)
+                e = coll.count_documents({key: self_id}, limit=1)
                 exist = e > 0
                 if exist:
                     if no_raise:
@@ -123,8 +118,8 @@ def _orm_delete(self: T, no_raise: bool = False) -> None:
                     else:
                         raise DeletionDeniedException()
             else:
-                key = oc.cdef.jconf.ref_key_encoding_strategy(f)
-                exist = oc.exist(**{key: ObjectId(self._id)}).exec()
+                key = oc.cdef.jconf.ref_name_strategy(f)
+                exist = oc.exist(**{key: self_id}).exec()
                 if exist:
                     if no_raise:
                         return
@@ -132,7 +127,7 @@ def _orm_delete(self: T, no_raise: bool = False) -> None:
                         raise DeletionDeniedException()
 
     collection = Connection.get_collection(self.__class__)
-    collection.delete_one({'_id': ObjectId(self._id)})
+    collection.delete_one({'_id': self_id})
 
     # delete chain - nullify
     for field in self.__class__.cdef.nullify_fields:
@@ -143,17 +138,13 @@ def _orm_delete(self: T, no_raise: bool = False) -> None:
                 oc = field.fdef.inst_cls
             f = cast(JField, field.foreign_field)
             if field.fdef.use_join_table:
-                jtname = Coder().join_table_name(
-                    self.__class__,
-                    field.name,
-                    oc,
-                    f.name)
+                jtname = join_table_name(field)
                 coll = Connection.from_class(self.__class__).collection(jtname)
                 key = ref_db_field_key(self.__class__.__name__, self.__class__)
-                coll.delete_many({key: ObjectId(self._id)})
+                coll.delete_many({key: self_id})
             else:
-                key = oc.cdef.jconf.ref_key_encoding_strategy(f)
-                for o in oc.iterate(**{key: ObjectId(self._id)}).exec():
+                key = oc.cdef.jconf.ref_name_strategy(f)
+                for o in oc.iterate(**{key: self_id}).exec():
                     setattr(o, f.name, None)
                     setattr(o, key, None)
                     o.save(skip_validation=True)
@@ -166,30 +157,26 @@ def _orm_delete(self: T, no_raise: bool = False) -> None:
             oc = field.fdef.inst_cls
         f = cast(JField, field.foreign_field)
         if field.fdef.fstore == FStore.LOCAL_KEY:
-            key = self.__class__.cdef.jconf.ref_key_encoding_strategy(field)
+            key = self.__class__.cdef.jconf.ref_name_strategy(field)
             if getattr(self, key) is not None:
                 item = oc.id(getattr(self, key)).optional.exec()
                 if item is not None:
                     item._orm_delete(no_raise=True)
         elif field.fdef.fstore == FStore.FOREIGN_KEY:
             if field.fdef.use_join_table:
-                jtname = Coder().join_table_name(
-                    self.__class__,
-                    field.name,
-                    oc,
-                    f.name)
+                jtname = join_table_name(field)
                 coll = Connection.from_class(self.__class__).collection(jtname)
                 key = ref_db_field_key(self.__class__.__name__, self.__class__)
                 other_key = ref_db_field_key(oc.__name__, oc)
-                for rel in coll.find({key: ObjectId(self._id)}):
+                for rel in coll.find({key: self_id}):
                     other_id = rel[other_key]
                     item = oc.id(other_id).optional.exec()
                     if item is not None:
                         item._orm_delete(no_raise=True)
-                coll.delete_many({key: ObjectId(self._id)})
+                coll.delete_many({key: self_id})
             else:
-                key = oc.cdef.jconf.ref_key_encoding_strategy(f)
-                for o in oc.iterate(**{key: ObjectId(self._id)}).exec():
+                key = oc.cdef.jconf.ref_name_strategy(f)
+                for o in oc.iterate(**{key: self_id}).exec():
                     o._orm_delete(no_raise=True)
 
     setattr(self, '_is_deleted', True)
@@ -203,7 +190,7 @@ def _orm_complete(self: T) -> None:
             if field.name not in self._partial_picks:
                 this_pick.append(field.name)
         elif field.fdef.fstore == FStore.LOCAL_KEY:
-            kr = self.__class__.cdef.jconf.ref_key_encoding_strategy
+            kr = self.__class__.cdef.jconf.ref_name_strategy
             ref_key = kr(field)
             if ref_key not in self._partial_picks:
                 this_pick.append(ref_key)
@@ -218,10 +205,10 @@ def _orm_restore(self: T) -> None:
     pass
 
 
-def pymongofy(class_: type) -> PymongoObject:
+def pymongofy(class_: type) -> PObject:
     # do not install methods for subclasses
     if hasattr(class_, '__is_pymongo__'):
-        return cast(PymongoObject, class_)
+        return cast(PObject, class_)
     # type marks
     setattr(class_, '__is_pymongo__', True)
     # public methods
@@ -246,9 +233,7 @@ def pymongofy(class_: type) -> PymongoObject:
         compound_fields: dict[str, list[JField]] = {}
         compound_ufields: dict[str, list[JField]] = {}
         for field in class_.cdef.fields:
-            fname = field.name
-            if class_.pconf.camelize_db_keys:
-                fname = camelize(field.name, False)
+            fname = class_.pconf.to_db_key(field.name)
             index = field.fdef.index
             unique = field.fdef.unique
             required = field.fdef.required
@@ -272,7 +257,7 @@ def pymongofy(class_: type) -> PymongoObject:
                     if ciname not in compound_fields:
                         compound_fields[ciname] = []
                     if field.fdef.fstore == FStore.LOCAL_KEY:
-                        res = field.fdef.cdef.jconf.ref_key_encoding_strategy
+                        res = field.fdef.cdef.jconf.ref_name_strategy
                         compound_fields[ciname].append(field)
                     else:
                         compound_fields[ciname].append(field)
@@ -281,7 +266,7 @@ def pymongofy(class_: type) -> PymongoObject:
                     if cuname not in compound_ufields:
                         compound_ufields[cuname] = []
                     if field.fdef.fstore == FStore.LOCAL_KEY:
-                        res = field.fdef.cdef.jconf.ref_key_encoding_strategy
+                        res = field.fdef.cdef.jconf.ref_name_strategy
                         compound_ufields[cuname].append(field)
                     else:
                         compound_ufields[cuname].append(field)
@@ -290,12 +275,11 @@ def pymongofy(class_: type) -> PymongoObject:
             keys: list[tuple[str, Any]] = []
             for field in fields:
                 if field.fdef.fstore == FStore.LOCAL_KEY:
-                    res = field.fdef.cdef.jconf.ref_key_encoding_strategy
+                    res = field.fdef.cdef.jconf.ref_name_strategy
                     key = res(field)
                 else:
                     key = field.name
-                if class_.pconf.camelize_db_keys:
-                    key = camelize(key, False)
+                key = class_.pconf.to_db_key(key)
                 if not field.fdef.required:
                     sparse = True
                 keys.append((key, ASCENDING))
@@ -307,12 +291,10 @@ def pymongofy(class_: type) -> PymongoObject:
             keys: list[tuple[str, Any]] = []
             for field in fields:
                 if field.fdef.fstore == FStore.LOCAL_KEY:
-                    res = field.fdef.cdef.jconf.ref_key_encoding_strategy
+                    res = field.fdef.cdef.jconf.ref_name_strategy
                     key = res(field)
                 else:
-                    key = field.name
-                if class_.pconf.camelize_db_keys:
-                    key = camelize(key, False)
+                    key = class_.pconf.to_db_key(field.name)
                 if not field.fdef.required:
                     sparse = True
                 keys.append((key, ASCENDING))
