@@ -13,13 +13,11 @@ from jsonclasses.fdef import FStore, FType
 from jsonclasses.jfield import JField
 from jsonclasses.mgraph import MGraph
 from jsonclasses.excs import ObjectNotFoundException
-from inflection import camelize
-from .coder import Coder
 from .decoder import Decoder
 from .connection import Connection
-from .pymongo_object import PymongoObject
-from .utils import ref_db_field_key, ref_db_field_keys
-T = TypeVar('T', bound=PymongoObject)
+from .pobject import PObject
+from .utils import idval, ref_db_field_key, ref_db_field_keys, join_table_name
+T = TypeVar('T', bound=PObject)
 U = TypeVar('U', bound='BaseQuery')
 V = TypeVar('V', bound='BaseListQuery')
 
@@ -38,19 +36,17 @@ class BaseQuery(Generic[T]):
         self.subqueries: list[Subquery] = []
 
     def include(self: U, name: str, query: Optional[BaseQuery] = None) -> U:
-        tcls = cast(type[PymongoObject], self._cls)
-        decoded_name = tcls.cdef.jconf.key_decoding_strategy(name)
+        tcls = cast(type[PObject], self._cls)
+        decoded_name = tcls.cdef.jconf.input_key_strategy(name)
         self.subqueries.append(Subquery(decoded_name, query))
         return self
 
     def _build_aggregate_pipeline(self: U) -> list[dict[str, Any]]:
-        cls = cast(type[PymongoObject], self._cls)
+        cls = cast(type[PObject], self._cls)
         result: list[dict[str, Any]] = []
         for subquery in self.subqueries:
             fname = subquery.name
-            dbfname = fname
-            if cls.pconf.camelize_db_keys:
-                dbfname = camelize(dbfname, False)
+            dbfname = cls.pconf.to_db_key(fname)
             field = cls.cdef.field_named(fname)
             if field.fdef.ftype == FType.LIST:
                 it = field.fdef.item_types.fdef.inst_cls
@@ -162,9 +158,7 @@ class BaseQuery(Generic[T]):
                             matcher = item.get('$match')
                             break
                     if field.fdef.use_join_table:
-                        coder = Coder()
-                        jt_name = coder.join_table_name(cls, field.name,
-                                                        it, field.foreign_field.name)
+                        jt_name = join_table_name(field)
                         this_key = ref_db_field_key(cls.__name__, cls)
                         that_key = ref_db_field_key(it.__name__, it)
                         pipeline: list[Any] = []
@@ -321,13 +315,13 @@ class BaseListQuery(BaseQuery[T]):
         if result.get('_includes') is not None:
             for item in result['_includes']:
                 if type(item) is str:
-                    tcls = cast(type[PymongoObject], self._cls)
-                    decoded_name = tcls.cdef.jconf.key_decoding_strategy(item)
+                    tcls = cast(type[PObject], self._cls)
+                    decoded_name = tcls.cdef.jconf.input_key_strategy(item)
                     self.subqueries.append(Subquery(decoded_name, None))
                 elif isinstance(item, dict):
                     for k, v in item.items():
-                        tcls = cast(type[PymongoObject], self._cls)
-                        decoded_key = tcls.cdef.jconf.key_decoding_strategy(k)
+                        tcls = cast(type[PObject], self._cls)
+                        decoded_key = tcls.cdef.jconf.input_key_strategy(k)
                         field = tcls.cdef.field_named(decoded_key)
                         fcls = field.foreign_class
                         if field.fdef.ftype == FType.LIST:
@@ -339,10 +333,9 @@ class BaseListQuery(BaseQuery[T]):
     def order(self: V, field_name: str, sort: Optional[int] = None) -> V:
         if self._sort is None:
             self._sort = []
-        tcls = cast(type[PymongoObject], self._cls)
-        decoded_name = tcls.cdef.jconf.key_decoding_strategy(field_name)
-        if tcls.pconf.camelize_db_keys:
-            decoded_name = camelize(decoded_name, False)
+        tcls = cast(type[PObject], self._cls)
+        decoded_name = tcls.cdef.jconf.input_key_strategy(field_name)
+        decoded_name = tcls.pconf.to_db_key(decoded_name)
         self._sort.append((decoded_name, sort or 1))
         return self
 
@@ -383,11 +376,7 @@ class BaseListQuery(BaseQuery[T]):
         if self._virtual is not None:
             for virtual in self._virtual:
                 _, field, obj = virtual
-                jtname = Coder().join_table_name(
-                    self._cls,
-                    field.name,
-                    field.foreign_class,
-                    field.foreign_field.name)
+                jtname = join_table_name(field)
                 thisref = ref_db_field_key(self._cls.__name__, self._cls)
                 thatref = ref_db_field_key(field.foreign_class.__name__, field.foreign_class)
                 and_mode = False
@@ -444,7 +433,7 @@ class BaseListQuery(BaseQuery[T]):
             if self._limit is not None:
                 result.append({'$limit': self._limit})
         if self._use_omit or self._use_pick:
-            kds = self._cls.cdef.jconf.key_decoding_strategy
+            kds = self._cls.cdef.jconf.input_key_strategy
             if self._omit and self._pick:
                 finalpick = list(set(self._pick) - set(self._omit))
                 finalpick = [kds(k) for k in finalpick]
@@ -459,7 +448,7 @@ class BaseListQuery(BaseQuery[T]):
                         if field.name not in omits:
                             finalpick.append(field.name)
                     elif field.fdef.fstore == FStore.LOCAL_KEY:
-                        rkes = self._cls.cdef.jconf.ref_key_encoding_strategy
+                        rkes = self._cls.cdef.jconf.ref_name_strategy
                         rk = rkes(field)
                         if rk not in omits:
                             finalpick.append(rk)
@@ -468,8 +457,7 @@ class BaseListQuery(BaseQuery[T]):
                 omit_primary = True
             else:
                 omit_primary = False
-            if self._cls.pconf.camelize_db_keys:
-                finalpick = [camelize(k, False) for k in finalpick]
+            finalpick = [self._cls.pconf.to_db_key(k) for k in finalpick]
             pdict = {k: 1 for k in finalpick}
             if omit_primary:
                 pdict['_id'] = 0
@@ -578,7 +566,8 @@ class BaseIDQuery(BaseQuery[T]):
 
     def _build_aggregate_pipeline(self: BaseIDQuery) -> list[dict[str, Any]]:
         list_query_results = self.list_query._build_aggregate_pipeline()
-        result = [{'$match': {'_id': ObjectId(self._id)}}]
+        idvalue = idval(self._cls.cdef.primary_field, self._id)
+        result = [{'$match': {'_id': idvalue}}]
         for v in list_query_results:
             if '$match' in v.keys():
                 continue
