@@ -1,6 +1,6 @@
 from __future__ import annotations
 from unittest import TestCase
-from jsonclasses_pymongo import Connection
+from jsonclasses_pymongo.connection import Connection
 from tests.classes.linked_account import LinkedAccount, LinkedBalance
 from tests.classes.linked_song import LinkedSinger, LinkedSong
 from tests.classes.linked_album import LinkedAlbum, LinkedArtist
@@ -62,7 +62,6 @@ class TestObjectInclude(TestCase):
         singer1 = LinkedSinger(name='michael').save()
         singer2 = LinkedSinger(name='victor').save()
         song = LinkedSong(name='song', singer_ids=[singer1.id, singer2.id])
-        song.singer_ids = [singer1.id, singer2.id] # TODO fix bug and remove this line
         song.save()
         result = song.include('singers')
         self.assertEqual(result, song)
