@@ -1,9 +1,9 @@
 from __future__ import annotations
-from datetime import date, datetime
+from datetime import date, datetime, time, timezone
 from unittest import TestCase
 from math import ceil
 from statistics import mean
-from jsonclasses_pymongo import Connection
+from jsonclasses_pymongo.connection import Connection
 from tests.classes.simple_animal import SimpleAnimal
 from tests.classes.simple_datetime import SimpleDatetime
 from tests.classes.simple_score import SimpleScore
@@ -232,6 +232,46 @@ class TestQuery(TestCase):
         result = SimpleSong.find('year[_eq]=2010').exec()
         self.assertEqual(len(result), 0)
 
+    def test_query_object_with_neq_int_object(self):
+        song = SimpleSong(name='Long', year=2020, artist='Thao')
+        song.save()
+        result = SimpleSong.find(year={'_neq': 2020}).exec()
+        self.assertEqual(len(result),0)
+        result = SimpleSong.find(year={'_neq': 2010}).exec()
+        self.assertEqual(len(result),1)
+        self.assertEqual(result[0].year, 2020)
+
+    def test_query_object_with_neq_int_object_string(self):
+        song = SimpleSong(name='Long', year=2020, artist='Thao')
+        song.save()
+        result = SimpleSong.find('year[_neq]=2020').exec()
+        self.assertEqual(len(result), 0)
+        result = SimpleSong.find('year[_neq]=2010').exec()
+        self.assertEqual(len(result), 1)
+        self.assertEqual(result[0].year, 2020)
+
+    def test_query_object_with_neq_null_int_object(self):
+        song = SimpleSong(name='Long', year=2020, artist='Thao')
+        song.save()
+        result = SimpleSong.find(year={'_null':'false','_neq': 2020}).exec()
+        self.assertEqual(len(result),0)
+        result = SimpleSong.find(year={'_null':'true','_neq': 2021}).exec()
+        self.assertEqual(len(result),0)
+        result = SimpleSong.find(year={'_null':'false','_neq': 2021}).exec()
+        self.assertEqual(len(result),1)
+        self.assertEqual(result[0].year, 2020)
+    
+    def test_query_object_with_neq_null_int_object_string(self):
+        song = SimpleSong(name='Long', year=2020, artist='Thao')
+        song.save()
+        result = SimpleSong.find('year[_neq]=2020&year[_null]=false').exec()
+        self.assertEqual(len(result), 0)
+        result = SimpleSong.find('year[_neq]=2021&year[_null]=true').exec()
+        self.assertEqual(len(result), 0)
+        result = SimpleSong.find('year[_neq]=2010&year[_null]=false').exec()
+        self.assertEqual(len(result), 1)
+        self.assertEqual(result[0].year, 2020)
+
     def test_query_object_with_not_int_object(self):
         song = SimpleSong(name='Long', year=2020, artist='Thao')
         song.save()
@@ -265,6 +305,46 @@ class TestQuery(TestCase):
         self.assertEqual(len(result), 1)
         self.assertEqual(result[0].name, 'Long')
 
+    def test_query_object_with_neq_str_object(self):
+        song = SimpleSong(name='Long', year=2020, artist='Thao')
+        song.save()
+        result = SimpleSong.find(name={'_neq':'Long'}).exec()
+        self.assertEqual(len(result), 0)
+        result = SimpleSong.find(name={'_neq':'ong'}).exec()
+        self.assertEqual(len(result),1)
+        self.assertEqual(result[0].name, 'Long')
+
+    def test_query_object_with_neq_str_object_string(self):
+        song = SimpleSong(name='Long', year=2020, artist='Thao')
+        song.save()
+        result = SimpleSong.find('name[_neq]=Long').exec()
+        self.assertEqual(len(result), 0)
+        result = SimpleSong.find('name[_neq]=ong').exec()
+        self.assertEqual(len(result),1)
+        self.assertEqual(result[0].name, 'Long')
+
+    def test_query_object_with_neq_null_str_object(self):
+        song = SimpleSong(name='Long', year=2020, artist='Thao')
+        song.save()
+        result = SimpleSong.find(name={'_neq':'Long','_null':'false'}).exec()
+        self.assertEqual(len(result), 0)
+        result = SimpleSong.find(name={'_neq':'ong','_null':'true'}).exec()
+        self.assertEqual(len(result), 0)
+        result = SimpleSong.find(name={'_neq':'ong','_null':'false'}).exec()
+        self.assertEqual(len(result),1)
+        self.assertEqual(result[0].name, 'Long')
+
+    def test_query_object_with_neq_null_str_object_string(self):
+        song = SimpleSong(name='Long', year=2020, artist='Thao')
+        song.save()
+        result = SimpleSong.find('name[_neq]=Long&name[_null]=false').exec()
+        self.assertEqual(len(result), 0)
+        result = SimpleSong.find('name[_neq]=ong&name[_null]=true').exec()
+        self.assertEqual(len(result), 0)
+        result = SimpleSong.find('name[_neq]=ong&name[_null]=false').exec()
+        self.assertEqual(len(result),1)
+        self.assertEqual(result[0].name, 'Long')
+
     def test_query_object_with_prefix_str_object(self):
         song = SimpleSong(name='Long', year=2020, artist='Thao')
         song.save()
@@ -337,75 +417,93 @@ class TestQuery(TestCase):
         self.assertEqual(len(result), 1)
         self.assertEqual(result[0].name, 'Ben')
 
-    def test_query_object_with_containsi_str_object(self):
+    def test_query_object_with_contains_insensitive_str_object(self):
         song = SimpleSong(name='Ben', year=2020, artist='Thao')
         song.save()
         song2 = SimpleSong(name='Lieng', year=2020, artist='Lieng')
         song2.save()
-        result = SimpleSong.find(name={'_containsi': 'b'}).exec()
+        result = SimpleSong.find(name={'_contains': 'b', '_mode': 'insensitive'}).exec()
         self.assertEqual(len(result), 1)
         self.assertEqual(result[0].name, 'Ben')
 
-    def test_query_object_with_containsi_str_object_str(self):
+    def test_query_object_with_contains_insensitive_str_object_str(self):
         song = SimpleSong(name='Ben', year=2020, artist='Thao')
         song.save()
         song2 = SimpleSong(name='Lieng', year=2020, artist='Lieng')
         song2.save()
-        result = SimpleSong.find('name[_containsi]=b').exec()
+        result = SimpleSong.find('name[_contains]=b&name[_mode]=insensitive').exec()
         self.assertEqual(len(result), 1)
         self.assertEqual(result[0].name, 'Ben')
 
-    def test_query_object_with_prefixi_str_object(self):
+    def test_query_object_with_prefix_insensitive_str_object(self):
         song = SimpleSong(name='Ben', year=2020, artist='Thao')
         song.save()
         song2 = SimpleSong(name='Lieng', year=2020, artist='Lieng')
         song2.save()
-        result = SimpleSong.find(name={'_prefixi': 'b'}).exec()
+        result = SimpleSong.find(name={'_prefix': 'b', '_mode': 'insensitive'}).exec()
         self.assertEqual(len(result), 1)
         self.assertEqual(result[0].name, 'Ben')
 
-    def test_query_object_with_prefixi_str_object_str(self):
+    def test_query_object_with_prefix_insensitive_str_object_str(self):
         song = SimpleSong(name='Ben', year=2020, artist='Thao')
         song.save()
         song2 = SimpleSong(name='Lieng', year=2020, artist='Lieng')
         song2.save()
-        result = SimpleSong.find('name[_prefixi]=b').exec()
+        result = SimpleSong.find('name[_prefix]=b&name[_mode]=insensitive').exec()
         self.assertEqual(len(result), 1)
         self.assertEqual(result[0].name, 'Ben')
 
-    def test_query_object_with_suffixi_str_object(self):
+    def test_query_object_with_insensitive_prefix_str_object_str(self):
+        song = SimpleSong(name='Ben', year=2020, artist='Thao')
+        song.save()
+        song2 = SimpleSong(name='Lieng', year=2020, artist='Lieng')
+        song2.save()
+        result = SimpleSong.find('name[_mode]=insensitive&name[_prefix]=b').exec()
+        self.assertEqual(len(result), 1)
+        self.assertEqual(result[0].name, 'Ben')
+
+    def test_query_object_with_suffix_insensitive_str_object(self):
         song = SimpleSong(name='BenS', year=2020, artist='Thao')
         song.save()
         song2 = SimpleSong(name='Lieng', year=2020, artist='Lieng')
         song2.save()
-        result = SimpleSong.find(name={'_suffixi': 's'}).exec()
+        result = SimpleSong.find(name={'_suffix': 's', '_mode': 'insensitive'}).exec()
         self.assertEqual(len(result), 1)
         self.assertEqual(result[0].name, 'BenS')
 
-    def test_query_object_with_suffixi_str_object_str(self):
+    def test_query_object_with_insensitive_suffix_str_object(self):
         song = SimpleSong(name='BenS', year=2020, artist='Thao')
         song.save()
         song2 = SimpleSong(name='Lieng', year=2020, artist='Lieng')
         song2.save()
-        result = SimpleSong.find('name[_suffixi]=s').exec()
+        result = SimpleSong.find(name={'_mode': 'insensitive','_suffix': 's'}).exec()
+        self.assertEqual(len(result), 1)
+    
+
+    def test_query_object_with_suffix_insensitive_str_object_str(self):
+        song = SimpleSong(name='BenS', year=2020, artist='Thao')
+        song.save()
+        song2 = SimpleSong(name='Lieng', year=2020, artist='Lieng')
+        song2.save()
+        result = SimpleSong.find('name[_suffix]=s&name[_mode]=insensitive').exec()
         self.assertEqual(len(result), 1)
         self.assertEqual(result[0].name, 'BenS')
 
-    def test_query_object_with_matchi_str_object(self):
+    def test_query_object_with_match_insensitive_str_object(self):
         song = SimpleSong(name='Lucy', year=2020, artist='Thao')
         song.save()
         song2 = SimpleSong(name='Lieng', year=2020, artist='Lieng')
         song2.save()
-        result = SimpleSong.find(name={'_matchi': 'C'}).exec()
+        result = SimpleSong.find(name={'_match': 'C', '_mode': 'insensitive'}).exec()
         self.assertEqual(len(result), 1)
         self.assertEqual(result[0].name, 'Lucy')
 
-    def test_query_object_with_matchi_str_object_str(self):
+    def test_query_object_with_match_insensitive_str_object_str(self):
         song = SimpleSong(name='Lucy', year=2020, artist='Thao')
         song.save()
         song2 = SimpleSong(name='Lieng', year=2020, artist='Lieng')
         song2.save()
-        result = SimpleSong.find('name[_matchi]=C').exec()
+        result = SimpleSong.find('name[_match]=C&name[_mode]=insensitive').exec()
         self.assertEqual(len(result), 1)
         self.assertEqual(result[0].name, 'Lucy')
 
@@ -532,14 +630,14 @@ class TestQuery(TestCase):
     def test_query_object_with_field_exists_str_object(self):
         song2 = SimpleSong(name='Lieng', year=2020, artist='Lieng')
         song2.save()
-        result = SimpleSong.find(name={'_field_exists': 'True'}).exec()
+        result = SimpleSong.find(name={'_null': 'False'}).exec()
         self.assertEqual(len(result), 1)
         self.assertEqual(result[0].name, 'Lieng')
 
     def test_query_object_with_field_exists_str_object_str(self):
         song2 = SimpleSong(name='Lieng', year=2020, artist='Lieng')
         song2.save()
-        result = SimpleSong.find('name[_field_exists]=True').exec()
+        result = SimpleSong.find('name[_null]=False').exec()
         self.assertEqual(len(result), 1)
         self.assertEqual(result[0].name, 'Lieng')
 
@@ -579,6 +677,46 @@ class TestQuery(TestCase):
         self.assertEqual(len(result), 1)
         self.assertEqual(result[0].name, 'tiger')
 
+    def test_query_object_with_neq_bool_object(self):
+        animal = SimpleAnimal(name='tiger', can_fly=False)
+        animal.save()
+        animal2 = SimpleAnimal(name='bird', can_fly=True)
+        animal2.save()
+        result = SimpleAnimal.find(can_fly={'_neq': 'False'}).exec()
+        self.assertEqual(len(result),1)
+        self.assertEqual(result[0].name, 'bird')
+
+    def test_query_object_with_neq_bool_object_str(self):
+        animal = SimpleAnimal(name='tiger', can_fly=False)
+        animal.save()
+        animal2 = SimpleAnimal(name='bird', can_fly=True)
+        animal2.save()
+        result = SimpleAnimal.find('canFly[_neq]=false').exec()
+        self.assertEqual(len(result),1)
+        self.assertEqual(result[0].name, 'bird')
+
+    def test_query_object_with_neq_null_bool_object(self):
+        animal = SimpleAnimal(name='tiger', can_fly=False)
+        animal.save()
+        animal2 = SimpleAnimal(name='bird', can_fly=True)
+        animal2.save()
+        result = SimpleAnimal.find(can_fly={'_neq': 'False','_null': 'true'}).exec()
+        self.assertEqual(len(result),0)
+        result = SimpleAnimal.find(can_fly={'_neq': 'False','_null': 'False'}).exec()
+        self.assertEqual(len(result),1)
+        self.assertEqual(result[0].name, 'bird')
+
+    def test_query_object_with_neq_null_bool_object_str(self):
+        animal = SimpleAnimal(name='tiger', can_fly=False)
+        animal.save()
+        animal2 = SimpleAnimal(name='bird', can_fly=True)
+        animal2.save()
+        result = SimpleAnimal.find('canFly[_neq]=false&canFly[_null]=true').exec()
+        self.assertEqual(len(result),0)
+        result = SimpleAnimal.find('canFly[_neq]=false&canFly[_null]=false').exec()
+        self.assertEqual(len(result),1)
+        self.assertEqual(result[0].name, 'bird')
+
     def test_query_object_with_date(self):
         d = SimpleDate(represents=date(2010, 7, 7))
         d.save()
@@ -607,22 +745,62 @@ class TestQuery(TestCase):
         self.assertEqual(len(results), 1)
         self.assertEqual(results[0].represents, d.represents)
 
-    def test_query_object_with_datetime(self):
-        d = SimpleDatetime(represents=datetime(2021, 6, 6, 12, 30))
+    def test_query_object_with_neq_data_object(self):
+        d = SimpleDate(represents=date(2010,7, 7))
         d.save()
-        results = SimpleDatetime.find(represents=datetime(2021, 6, 6, 12, 30)).exec()
+        results = SimpleDate.find(represents={'_neq': '2010-07-07'}).exec()
+        self.assertEqual(len(results), 0)
+        results = SimpleDate.find(represents={'_neq': '2010-07-08'}).exec()
+        self.assertEqual(len(results), 1)
+        self.assertEqual(results[0].represents, d.represents)
+
+    def test_query_object_with_neq_data_object_string(self):
+        d = SimpleDate(represents=date(2010,7, 7))
+        d.save()
+        results = SimpleDate.find('represents[_neq]=2010-07-07').exec()
+        self.assertEqual(len(results), 0)
+        results = SimpleDate.find('represents[_neq]=2010-07-08').exec()
+        self.assertEqual(len(results), 1)
+        self.assertEqual(results[0].represents, d.represents)
+
+    def test_query_object_with_neq_null_data_object(self):
+        d = SimpleDate(represents=date(2010,7, 7))
+        d.save()
+        results = SimpleDate.find(represents={'_neq': '2010-07-07'}).exec()
+        self.assertEqual(len(results), 0)
+        results = SimpleDate.find(represents={'_neq': '2010-07-08','_null': 'true'}).exec()
+        self.assertEqual(len(results), 0)
+        results = SimpleDate.find(represents={'_neq': '2010-07-08','_null': 'false'}).exec()
+        self.assertEqual(len(results), 1)
+        self.assertEqual(results[0].represents, d.represents)
+
+    def test_query_object_with_neq_null_data_object_string(self):
+        d = SimpleDate(represents=date(2010,7, 7))
+        d.save()
+        results = SimpleDate.find('represents[_neq]=2010-07-07').exec()
+        self.assertEqual(len(results), 0)
+        results = SimpleDate.find('represents[_neq]=2010-07-08&represents[_null]=true').exec()
+        self.assertEqual(len(results), 0)
+        results = SimpleDate.find('represents[_neq]=2010-07-08&represents[_null]=false').exec()
+        self.assertEqual(len(results), 1)
+        self.assertEqual(results[0].represents, d.represents)
+
+    def test_query_object_with_datetime(self):
+        d = SimpleDatetime(represents=datetime(2021, 6, 6, 12, 30, tzinfo=timezone.utc))
+        d.save()
+        results = SimpleDatetime.find(represents=datetime(2021, 6, 6, 12, 30, tzinfo=timezone.utc)).exec()
         self.assertEqual(len(results), 1)
         self.assertEqual(results[0].represents, d.represents)
 
     def test_query_object_with_datetime_string(self):
-        d = SimpleDatetime(represents=datetime(2021, 6, 6, 12, 30, 0))
+        d = SimpleDatetime(represents=datetime(2021, 6, 6, 12, 30, 0, tzinfo=timezone.utc))
         d.save()
         results = SimpleDatetime.find('represents=2021-06-06 12:30:00').exec()
         self.assertEqual(len(results), 1)
         self.assertEqual(results[0].represents, d.represents)
 
     def test_query_object_with_datetime_object(self):
-        d = SimpleDatetime(represents=datetime(2021, 6, 6, 12, 30, 0))
+        d = SimpleDatetime(represents=datetime(2021, 6, 6, 12, 30, 0, tzinfo=timezone.utc))
         d.save()
         results = SimpleDatetime.find(represents={'_eq': '2021-06-06 12:30:00'}).exec()
         self.assertEqual(len(results), 1)
